##  @package PACKAGENAME
#   DESCRIPTION

import sys
import os


##  CLASS DESCRIPTION
#   \version 0.1.0 <br>
#   \details
class ExampleClass(object):


    ##  This is the constructor
    #   @param
    #   @param
    def __init__(self):
        print("ExampleClass init")
        pass




if __name__ == '__main__':
    pass



